lib Package
===========

:mod:`lib` Package
------------------

.. automodule:: stoqlib.lib
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`algorithms` Module
------------------------

.. automodule:: stoqlib.lib.algorithms
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`appinfo` Module
---------------------

.. automodule:: stoqlib.lib.appinfo
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`barcode` Module
---------------------

.. automodule:: stoqlib.lib.barcode
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`boleto` Module
--------------------

.. automodule:: stoqlib.lib.boleto
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cardinal_formatters` Module
---------------------------------

.. automodule:: stoqlib.lib.cardinal_formatters
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cardinals_en` Module
--------------------------

.. automodule:: stoqlib.lib.cardinals_en
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cardinals_ptbr` Module
----------------------------

.. automodule:: stoqlib.lib.cardinals_ptbr
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`component` Module
-----------------------

.. automodule:: stoqlib.lib.component
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`configparser` Module
--------------------------

.. automodule:: stoqlib.lib.configparser
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`console` Module
---------------------

.. automodule:: stoqlib.lib.console
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cookie` Module
--------------------

.. automodule:: stoqlib.lib.cookie
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`countries` Module
-----------------------

.. automodule:: stoqlib.lib.countries
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`crashreport` Module
-------------------------

.. automodule:: stoqlib.lib.crashreport
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`daemonutils` Module
-------------------------

.. automodule:: stoqlib.lib.daemonutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dateconstants` Module
---------------------------

.. automodule:: stoqlib.lib.dateconstants
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`defaults` Module
----------------------

.. automodule:: stoqlib.lib.defaults
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`devicemanager` Module
---------------------------

.. automodule:: stoqlib.lib.devicemanager
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`diffutils` Module
-----------------------

.. automodule:: stoqlib.lib.diffutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`doctestloader` Module
---------------------------

.. automodule:: stoqlib.lib.doctestloader
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`event` Module
-------------------

.. automodule:: stoqlib.lib.event
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`formatters` Module
------------------------

.. automodule:: stoqlib.lib.formatters
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`imageutils` Module
------------------------

.. automodule:: stoqlib.lib.imageutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`interfaces` Module
------------------------

.. automodule:: stoqlib.lib.interfaces
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`introspection` Module
---------------------------

.. automodule:: stoqlib.lib.introspection
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`invoice` Module
---------------------

.. automodule:: stoqlib.lib.invoice
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`latscii` Module
---------------------

.. automodule:: stoqlib.lib.latscii
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`message` Module
---------------------

.. automodule:: stoqlib.lib.message
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`osutils` Module
---------------------

.. automodule:: stoqlib.lib.osutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parameters` Module
------------------------

.. automodule:: stoqlib.lib.parameters
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`payment` Module
---------------------

.. automodule:: stoqlib.lib.payment
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pdf` Module
-----------------

.. automodule:: stoqlib.lib.pdf
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pluginmanager` Module
---------------------------

.. automodule:: stoqlib.lib.pluginmanager
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`prettydate` Module
------------------------

.. automodule:: stoqlib.lib.prettydate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`process` Module
---------------------

.. automodule:: stoqlib.lib.process
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`settings` Module
----------------------

.. automodule:: stoqlib.lib.settings
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sintegra` Module
----------------------

.. automodule:: stoqlib.lib.sintegra
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sintegragenerator` Module
-------------------------------

.. automodule:: stoqlib.lib.sintegragenerator
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`template` Module
----------------------

.. automodule:: stoqlib.lib.template
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`translation` Module
-------------------------

.. automodule:: stoqlib.lib.translation
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`unittestutils` Module
---------------------------

.. automodule:: stoqlib.lib.unittestutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`uptime` Module
--------------------

.. automodule:: stoqlib.lib.uptime
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`validators` Module
------------------------

.. automodule:: stoqlib.lib.validators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`webservice` Module
------------------------

.. automodule:: stoqlib.lib.webservice
    :members:
    :undoc-members:
    :show-inheritance:
